@@ -5,12 +5,14 @@ __all__ = [
     'abspath',
     'pushd_popd',
     'unzip_file_to_dir',
+    'atomic_write',
 ]
 
+from atomicwrites import atomic_write as atomic_write_, AtomicWriter
 from tempfile import TemporaryDirectory
 import contextlib
-from os import getcwd, chdir
-import os.path
+from os import getcwd, chdir, stat, fchmod, umask
+from os.path import exists, abspath as abspath_
 
 from zipfile import ZipFile
 
@@ -22,7 +24,7 @@ def abspath(url):
     """
     if url.startswith('file://'):
         url = url[len('file://'):]
-    return os.path.abspath(url)
+    return abspath_(url)
 
 @contextlib.contextmanager
 def pushd_popd(newcwd=None, tempdir=False):
@@ -54,3 +56,24 @@ def unzip_file_to_dir(path_to_zip, output_directory):
     z.close()
 
 
+
+# ht @pabs3
+# https://github.com/untitaker/python-atomicwrites/issues/42
+class AtomicWriterPerms(AtomicWriter):
+    def get_fileobject(self, **kwargs):
+        f = super().get_fileobject(**kwargs)
+        try:
+            mode = stat(self._path).st_mode
+        except FileNotFoundError:
+            # Creating a new file, emulate what os.open() does
+            mask = umask(0)
+            umask(mask)
+            mode = 0o664 & ~mask
+        fd = f.fileno()
+        fchmod(fd, mode)
+        return f
+
+@contextlib.contextmanager
+def atomic_write(fpath):
+    with atomic_write_(fpath, writer_cls=AtomicWriterPerms, overwrite=True) as f:
+        yield f
